@@ -7,6 +7,10 @@ from .cost_centers import CostCenters
 from .projects import Projects
 from .categories import Categories
 from .expense_fields import ExpenseFields
+from .expenses import Expenses
+from .reports import Reports
+from .merchants import Merchants
+from .tax_groups import TaxGroups
 from ..version import version
 
 role = 'fyler'
@@ -16,3 +20,7 @@ cost_centers = CostCenters(version, role)
 categories = Categories(version, role)
 projects = Projects(version, role)
 expense_fields = ExpenseFields(version, role)
+expenses = Expenses(version, role)
+reports = Reports(version, role)
+merchants = Merchants(version, role)
+tax_groups = TaxGroups(version, role)
